==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/ja.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "パスワードは %s 文字以上である必要があります",
    "Password needs to contain at least one lower and one upper case character." : "パスワードは1つ以上の大文字と小文字をそれぞれ含む必要があります",
    "Password needs to contain at least one numeric character." : "パスワードは1つ以上の数字を含む必要があります",
    "Password needs to contain at least one special character." : "パスワードは1つ以上の特別な文字を含む必要があります",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "パスワードは最も一般的なパスワード1,000,000個の中に入っています。もっと違うものにしてください。",
    "Password policy" : "パスワードポリシー",
    "Allows admins to configure a password policy" : "管理者がパスワードポリシーを設定することを許可します",
    "Minimal length" : "最小の長さ",
    "Forbid common passwords" : "一般的なパスワードを禁止する",
    "Enforce upper and lower case characters" : "大文字と小文字を必ず含む",
    "Enforce numeric characters" : "数字を必ず含む",
    "Enforce special characters" : "記号を必ず含む",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "haveibeenpwned.comの侵害されたパスワードのリストと比較してパスワードをチェックする",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "このチェックでは、パスワードのハッシュを生成して先頭5文字をhaveibeenpwned.com APIに送信し、その5文字から始まるすべてのハッシュリストを取得します。 そして、パスワードハッシュが結果セットに含まれているかどうかNextcloudサーバーをチェックします。",
    "Password need to be at least %s characters long" : "パスワードは %s 文字以上である必要があります",
    "Password need to contain at least one lower case character and one upper case character." : "パスワードは1つ以上の大文字と小文字をそれぞれ含む必要があります",
    "Password need to contain at least one numeric character." : "パスワードは1つ以上の数字を含む必要があります",
    "Password need to contain at least one special character." : "パスワードは1つ以上の特別な文字を含む必要があります",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "パスワードは最も一般的なパスワード1,000,000個の中に入っています。ほかのものを選択してください",
    "Check password against the list of breached passwords from haveibeenpwnd.com" : "haveibeenpwned.comの侵害されたパスワードのリストと比較してパスワードをチェックする"
},
"nplurals=1; plural=0;");

==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/ja.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "パスワードは %s 文字以上である必要があります",
    "Password needs to contain at least one lower and one upper case character." : "パスワードは1つ以上の大文字と小文字をそれぞれ含む必要があります",
    "Password needs to contain at least one numeric character." : "パスワードは1つ以上の数字を含む必要があります",
    "Password needs to contain at least one special character." : "パスワードは1つ以上の特別な文字を含む必要があります",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "パスワードは最も一般的なパスワード1,000,000個の中に入っています。もっと違うものにしてください。",
    "Password is present in compromised password list. Please choose a different password." : "現在のパスワードは危険なパスワードリストに含まれるものです。別のパスワードを選択してください。",
    "Password policy" : "パスワードポリシー",
    "Allows admins to configure a password policy" : "管理者がパスワードポリシーを設定することを許可します",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "管理者が事前に一定の制約をパスワードに課すことを許可します。（例：最小の長さを強制）",
    "Minimal length" : "最小の長さ",
    "Forbid common passwords" : "一般的なパスワードを禁止する",
    "Enforce upper and lower case characters" : "大文字と小文字を必ず含む",
    "Enforce numeric characters" : "数字を必ず含む",
    "Enforce special characters" : "記号を必ず含む",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "haveibeenpwned.comの侵害されたパスワードのリストと比較してパスワードをチェックする",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "このチェックでは、パスワードのハッシュを生成して先頭5文字をhaveibeenpwned.com APIに送信し、その5文字から始まるすべてのハッシュリストを取得します。 そして、パスワードハッシュが結果セットに含まれているかどうかNextcloudサーバーをチェックします。",
    "Password need to be at least %s characters long" : "パスワードは %s 文字以上である必要があります",
    "Password need to contain at least one lower case character and one upper case character." : "パスワードは1つ以上の大文字と小文字をそれぞれ含む必要があります",
    "Password need to contain at least one numeric character." : "パスワードは1つ以上の数字を含む必要があります",
    "Password need to contain at least one special character." : "パスワードは1つ以上の特別な文字を含む必要があります",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "パスワードは最も一般的なパスワード1,000,000個の中に入っています。ほかのものを選択してください",
    "Check password against the list of breached passwords from haveibeenpwnd.com" : "haveibeenpwned.comの侵害されたパスワードのリストと比較してパスワードをチェックする"
},
"nplurals=1; plural=0;");
